# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateProduct(BaseModel):
    create_product: Optional["CreateProductCreateProduct"] = Field(
        alias="createProduct"
    )


class CreateProductCreateProduct(BaseModel):
    id: str
    name: str


CreateProduct.model_rebuild()
