# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import ContentSourceTypes


class RetrieveView(BaseModel):
    retrieve_view: Optional["RetrieveViewRetrieveView"] = Field(alias="retrieveView")


class RetrieveViewRetrieveView(BaseModel):
    results: Optional[List[Optional["RetrieveViewRetrieveViewResults"]]]


class RetrieveViewRetrieveViewResults(BaseModel):
    type: Optional[ContentSourceTypes]
    content: "RetrieveViewRetrieveViewResultsContent"
    text: str
    metadata: Optional[str]
    relevance: float
    start_time: Optional[Any] = Field(alias="startTime")
    end_time: Optional[Any] = Field(alias="endTime")
    page_number: Optional[int] = Field(alias="pageNumber")
    frame_number: Optional[int] = Field(alias="frameNumber")


class RetrieveViewRetrieveViewResultsContent(BaseModel):
    id: str


RetrieveView.model_rebuild()
RetrieveViewRetrieveView.model_rebuild()
RetrieveViewRetrieveViewResults.model_rebuild()
