# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteView(BaseModel):
    delete_view: Optional["DeleteViewDeleteView"] = Field(alias="deleteView")


class DeleteViewDeleteView(BaseModel):
    id: str
    state: EntityState


DeleteView.model_rebuild()
