# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateCategory(BaseModel):
    create_category: Optional["CreateCategoryCreateCategory"] = Field(
        alias="createCategory"
    )


class CreateCategoryCreateCategory(BaseModel):
    id: str
    name: str


CreateCategory.model_rebuild()
