# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountUsers(BaseModel):
    count_users: Optional["CountUsersCountUsers"] = Field(alias="countUsers")


class CountUsersCountUsers(BaseModel):
    count: Optional[Any]


CountUsers.model_rebuild()
