# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpsertLabel(BaseModel):
    upsert_label: Optional["UpsertLabelUpsertLabel"] = Field(alias="upsertLabel")


class UpsertLabelUpsertLabel(BaseModel):
    id: str
    name: str


UpsertLabel.model_rebuild()
