# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountViews(BaseModel):
    count_views: Optional["CountViewsCountViews"] = Field(alias="countViews")


class CountViewsCountViews(BaseModel):
    count: Optional[Any]


CountViews.model_rebuild()
