# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAlert(BaseModel):
    delete_alert: Optional["DeleteAlertDeleteAlert"] = Field(alias="deleteAlert")


class DeleteAlertDeleteAlert(BaseModel):
    id: str
    state: EntityState


DeleteAlert.model_rebuild()
