# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountMedicalDrugClasses(BaseModel):
    count_medical_drug_classes: Optional[
        "CountMedicalDrugClassesCountMedicalDrugClasses"
    ] = Field(alias="countMedicalDrugClasses")


class CountMedicalDrugClassesCountMedicalDrugClasses(BaseModel):
    count: Optional[Any]


CountMedicalDrugClasses.model_rebuild()
